==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/problemreporter/kdevproblemreporter.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=emblem-important
Exec=blubb
Comment=This plugin shows errors in source code.
Comment[bg]=Тази приставка показва грешки в изходния код.
Comment[bs]=Ovaj dodatak prikazuje greške u izvršnom kodu.
Comment[ca]=Aquest connector permet mostrar errors en el codi font.
Comment[ca@valencia]=Este connector permet mostrar errors en el codi font.
Comment[da]=Dette plugin viser fejl i kildekoden.
Comment[de]=Dieses Modul zeigt Fehler im Quelltext an.
Comment[el]=Αυτό το πρόσθετο εμφανίζει τα λάθη στον πηγαίο κώδικα.
Comment[en_GB]=This plugin shows errors in source code.
Comment[es]=Este complemento muestra errores en el código fuente.
Comment[et]=See plugin näitab vigu lähtekoodis.
Comment[fi]=Tämä liitännäinen näyttää virheet lähdekoodissa.
Comment[fr]=Ce module externe affiche les erreurs dans le code source.
Comment[gl]=Esta extensión mostra erros no código fonte.
Comment[hu]=Ez a bővítmény megjeleníti a hibákat a forráskódban.
Comment[it]=Questa estensione mostra gli errori nel codice sorgente.
Comment[kk]=Бастапқы код қателерін көрсететін плагині.
Comment[nb]=Dette programtillegget viser feil i kildekode.
Comment[nds]=Dit Moduul wiest Fehlers binnen Bornkode.
Comment[nl]=Deze plugin toont fouten in broncode
Comment[pl]=Ta wtyczka pokazuje błędy w kodzie źródłowym.
Comment[pt]=Este 'plugin' apresenta os erros no código-fonte.
Comment[pt_BR]=Este plugin apresenta os erros no código-fonte.
Comment[ru]=Это расширение показывает ошибки в исходном коде.
Comment[sk]=Tento plugin ukáže chyby v zdrojovom kóde.
Comment[sl]=Vstavek prikazuje napake v izvorni kodi.
Comment[sv]=Insticksprogrammet visar fel i källkod.
Comment[tr]=Bu eklenti kaynak kod içerisindeki hataları gösterir.
Comment[uk]=За допомогою цього додатка можна переглянути повідомлення про помилки у коді.
Comment[x-test]=xxThis plugin shows errors in source code.xx
Comment[zh_CN]=此插件显示源代码中的错误。
Comment[zh_TW]=此外掛程式顯示源碼中的錯誤。
Name=Problem Reporter View
Name[bg]=Преглед на съобщенията за грешки
Name[bs]=Pregled pomoću prikazivača problema
Name[ca]=Vista del notificador de problemes
Name[ca@valencia]=Vista del notificador de problemes
Name[da]=Visning af problemrapportering
Name[de]=Ansicht für Fehlerberichte
Name[el]=Προβολή ανταποκριτή προβλημάτων
Name[en_GB]=Problem Reporter View
Name[es]=Vista del notificador de problemas
Name[et]=Probleemide teavitaja vaade
Name[fi]=Ongelmailmoittajanäkymä
Name[fr]=Vue du rapporteur de problèmes
Name[gl]=Vista do relator de problemas
Name[hu]=Hibajelentő nézet
Name[it]=Vista segnalazione problemi
Name[ja]=問題レポータービュー
Name[kk]=Мәселе хабарлағыш көрінісі
Name[nb]=Problemmeldervisning
Name[nds]=Problemsöök-Ansicht
Name[nl]=Probleemrapporteuroverzicht
Name[pl]=Widok raportów o problemach
Name[pt]=Área de Relatórios de Erros
Name[pt_BR]=Área de Relatórios de Erros
Name[ru]=Панель диагностики проблем
Name[sk]=Pohľad na zadávač problémov
Name[sl]=Prikaz poročevalca o težavah
Name[sv]=Problemrapporteringsvy
Name[tr]=Sorun Bildirici Görünümü
Name[ug]=مەسىلە مەلۇم قىلغۇچ كۆرۈنۈشى
Name[uk]=Перегляд інструмента звітування про проблеми
Name[x-test]=xxProblem Reporter Viewxx
Name[zh_CN]=错误汇报视图
Name[zh_TW]=問題回報器檢視
GenericName=Problem Reporter
GenericName[bg]=Съобщения за грешки
GenericName[bs]=Prikazivač problema
GenericName[ca]=Notificador de problemes
GenericName[ca@valencia]=Notificador de problemes
GenericName[da]=Problemrapportering
GenericName[de]=Fehlerberichte
GenericName[el]=Ανταποκριτής προβλημάτων
GenericName[en_GB]=Problem Reporter
GenericName[es]=Notificador de problemas
GenericName[et]=Probleemide teavitaja
GenericName[fi]=Ongelmailmoittaja
GenericName[fr]=Rapporteur de problèmes
GenericName[gl]=Relator de problemas
GenericName[hu]=Hibajelentő
GenericName[it]=Segnalazione problemi
GenericName[ja]=問題レポーター
GenericName[kk]=Мәселе хабарлағышы
GenericName[nb]=Problemmelder
GenericName[nds]=Problemsöök
GenericName[nl]=Probleemrapporteur
GenericName[pl]=Raporty o problemach
GenericName[pt]=Relato de Problemas
GenericName[pt_BR]=Relato de Problemas
GenericName[ru]=Диагностика проблем
GenericName[sk]=Zadávač problémov
GenericName[sl]=Poročevalec o težavah
GenericName[sv]=Problemrapportör
GenericName[tr]=Sorun Bildirici
GenericName[ug]=مەسىلە مەلۇم قىلغۇچ
GenericName[uk]=Сповіщення про проблеми
GenericName[x-test]=xxProblem Reporterxx
GenericName[zh_CN]=错误汇报
GenericName[zh_TW]=問題回報器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevproblemreporter
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevproblemreporter
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.2.tar.xz: kdevplatform-1.7.2/plugins/problemreporter/kdevproblemreporter.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=emblem-important
Exec=blubb
Comment=This plugin shows errors in source code.
Comment[bg]=Тази приставка показва грешки в изходния код.
Comment[bs]=Ovaj dodatak prikazuje greške u izvršnom kodu.
Comment[ca]=Aquest connector permet mostrar errors en el codi font.
Comment[ca@valencia]=Este connector permet mostrar errors en el codi font.
Comment[da]=Dette plugin viser fejl i kildekoden.
Comment[de]=Dieses Modul zeigt Fehler im Quelltext an.
Comment[el]=Αυτό το πρόσθετο εμφανίζει τα λάθη στον πηγαίο κώδικα.
Comment[en_GB]=This plugin shows errors in source code.
Comment[es]=Este complemento muestra errores en el código fuente.
Comment[et]=See plugin näitab vigu lähtekoodis.
Comment[fi]=Tämä liitännäinen näyttää virheet lähdekoodissa.
Comment[fr]=Ce module externe affiche les erreurs dans le code source.
Comment[gl]=Esta extensión mostra erros no código fonte.
Comment[hu]=Ez a bővítmény megjeleníti a hibákat a forráskódban.
Comment[it]=Questa estensione mostra gli errori nel codice sorgente.
Comment[kk]=Бастапқы код қателерін көрсететін плагині.
Comment[nb]=Dette programtillegget viser feil i kildekode.
Comment[nds]=Dit Moduul wiest Fehlers binnen Bornkode.
Comment[nl]=Deze plugin toont fouten in broncode
Comment[pl]=Ta wtyczka pokazuje błędy w kodzie źródłowym.
Comment[pt]=Este 'plugin' apresenta os erros no código-fonte.
Comment[pt_BR]=Este plugin apresenta os erros no código-fonte.
Comment[ru]=Это расширение показывает ошибки в исходном коде.
Comment[sk]=Tento plugin ukáže chyby v zdrojovom kóde.
Comment[sl]=Vstavek prikazuje napake v izvorni kodi.
Comment[sv]=Insticksprogrammet visar fel i källkod.
Comment[tr]=Bu eklenti kaynak kod içerisindeki hataları gösterir.
Comment[uk]=За допомогою цього додатка можна переглянути повідомлення про помилки у коді.
Comment[x-test]=xxThis plugin shows errors in source code.xx
Comment[zh_CN]=此插件显示源代码中的错误。
Comment[zh_TW]=此外掛程式顯示源碼中的錯誤。
Name=Problem Reporter View
Name[bg]=Преглед на съобщенията за грешки
Name[bs]=Pregled pomoću prikazivača problema
Name[ca]=Vista del notificador de problemes
Name[ca@valencia]=Vista del notificador de problemes
Name[da]=Visning af problemrapportering
Name[de]=Ansicht für Fehlerberichte
Name[el]=Προβολή ανταποκριτή προβλημάτων
Name[en_GB]=Problem Reporter View
Name[es]=Vista del notificador de problemas
Name[et]=Probleemide teavitaja vaade
Name[fi]=Ongelmailmoitinnäkymä
Name[fr]=Vue du rapporteur de problèmes
Name[gl]=Vista do relator de problemas
Name[hu]=Hibajelentő nézet
Name[it]=Vista segnalazione problemi
Name[ja]=問題レポータービュー
Name[kk]=Мәселе хабарлағыш көрінісі
Name[nb]=Problemmeldervisning
Name[nds]=Problemsöök-Ansicht
Name[nl]=Probleemrapporteuroverzicht
Name[pl]=Widok raportów o problemach
Name[pt]=Área de Relatórios de Erros
Name[pt_BR]=Área de Relatórios de Erros
Name[ru]=Панель диагностики проблем
Name[sk]=Pohľad na zadávač problémov
Name[sl]=Prikaz poročevalca o težavah
Name[sv]=Problemrapporteringsvy
Name[tr]=Sorun Bildirici Görünümü
Name[ug]=مەسىلە مەلۇم قىلغۇچ كۆرۈنۈشى
Name[uk]=Перегляд інструмента звітування про проблеми
Name[x-test]=xxProblem Reporter Viewxx
Name[zh_CN]=错误汇报视图
Name[zh_TW]=問題回報器檢視
GenericName=Problem Reporter
GenericName[bg]=Съобщения за грешки
GenericName[bs]=Prikazivač problema
GenericName[ca]=Notificador de problemes
GenericName[ca@valencia]=Notificador de problemes
GenericName[da]=Problemrapportering
GenericName[de]=Fehlerberichte
GenericName[el]=Ανταποκριτής προβλημάτων
GenericName[en_GB]=Problem Reporter
GenericName[es]=Notificador de problemas
GenericName[et]=Probleemide teavitaja
GenericName[fi]=Ongelmailmoitin
GenericName[fr]=Rapporteur de problèmes
GenericName[gl]=Relator de problemas
GenericName[hu]=Hibajelentő
GenericName[it]=Segnalazione problemi
GenericName[ja]=問題レポーター
GenericName[kk]=Мәселе хабарлағышы
GenericName[nb]=Problemmelder
GenericName[nds]=Problemsöök
GenericName[nl]=Probleemrapporteur
GenericName[pl]=Raporty o problemach
GenericName[pt]=Relato de Problemas
GenericName[pt_BR]=Relato de Problemas
GenericName[ru]=Диагностика проблем
GenericName[sk]=Zadávač problémov
GenericName[sl]=Poročevalec o težavah
GenericName[sv]=Problemrapportör
GenericName[tr]=Sorun Bildirici
GenericName[ug]=مەسىلە مەلۇم قىلغۇچ
GenericName[uk]=Сповіщення про проблеми
GenericName[x-test]=xxProblem Reporterxx
GenericName[zh_CN]=错误汇报
GenericName[zh_TW]=問題回報器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevproblemreporter
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevproblemreporter
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI
